@@ -8,8 +8,9 @@ use FindBin;
 use lib File::Spec->catdir( $FindBin::Bin, 'lib' );
 use Test::Smoke::Mailer;
 
-use vars qw( $VERSION $conf );
-$VERSION = '0.004';
+use Test::Smoke;
+use vars qw( $VERSION );
+$VERSION = '0.007';
 
 my %opt = (
     type    => undef,
@@ -20,7 +21,7 @@ my %opt = (
     mserver => '',
     v       => 0,
 
-    config  => '',
+    config  => undef,
     help    => 0,
     man     => 0,
 );
@@ -39,7 +40,7 @@ mailrpt.pl - Send the smoke report by mail
 
 or
 
-    $ ./mailrpt.pl -c smokeperl_config
+    $ ./mailrpt.pl -c smokecurrent_config
 
 =head1 OPTIONS
 
@@ -87,26 +88,33 @@ GetOptions( \%opt,
 
     'help|h', 'man|m',
 
-    'config|c=s',
+    'config|c:s',
 ) or do_pod2usage( verbose => 1 );
 
 $opt{man}  and do_pod2usage( verbose => 2, exitval => 0 );
 $opt{help} and do_pod2usage( verbose => 1, exitval => 0 );
 
-if ( $opt{config} && -f $opt{config} ) {
-    require $opt{config};
+if ( defined $opt{config} ) {
+    $opt{config} eq "" and $opt{config} = 'smokecurrent_config';
+    read_config( $opt{config} ) or do {
+        my $config_name = File::Spec->catfile( $FindBin::Bin, $opt{config} );
+        read_config( $config_name );
+    };
 
-    foreach my $option ( keys %opt ) {
-        if ( $option eq 'type' ) {
-            $opt{type} ||= $conf->{mail_type};
-        } elsif ( exists $conf->{ $option } ) {
-            $opt{ $option } ||= $conf->{ $option }
+    unless ( Test::Smoke->config_error ) {
+        foreach my $option ( keys %opt ) {
+            if ( $option eq 'type' ) {
+                $opt{type} ||= $conf->{mail_type};
+            } elsif ( exists $conf->{ $option } ) {
+                $opt{ $option } ||= $conf->{ $option }
+            }
         }
+    } else {
+        warn "WARNING: Could not process '$opt{config}': " . 
+             Test::Smoke->config_error . "\n";
     }
 }
 
-$opt{ $_ } ||= $defaults->{ $_ } foreach keys %$defaults;
-
 exists $valid_type{ $opt{type} } or do_pod2usage( verbose => 0 );
 
 $opt{ddir} && -d $opt{ddir} or do_pod2usage( verbose => 0 );
