@@ -8,8 +8,9 @@ use FindBin;
 use lib File::Spec->catdir( $FindBin::Bin, 'lib' );
 use Test::Smoke::Patcher;
 
-use vars qw( $VERSION $conf );
-$VERSION = '0.001';
+use Test::Smoke;
+use vars qw( $VERSION );
+$VERSION = '0.005';
 
 my %opt = (
     type    => 'multi',
@@ -17,7 +18,7 @@ my %opt = (
     pfile   => '',
     v       => 0,
 
-    config  => '',
+    config  => undef,
     help    => 0,
     man     => 0,
 );
@@ -36,7 +37,7 @@ patchtree.pl - Patch the sourcetree
 
 or
 
-    $ ./mailrpt.pl -c smokeperl_config
+    $ ./mailrpt.pl -c smokecurrent_config
 
 =head1 OPTIONS
 
@@ -66,25 +67,34 @@ GetOptions( \%opt,
 
     'help|h', 'man|m',
 
-    'config|c=s',
+    'config|c:s',
 ) or do_pod2usage( verbose => 1 );
 
 $opt{man}  and do_pod2usage( verbose => 2, exitval => 0 );
 $opt{help} and do_pod2usage( verbose => 1, exitval => 0 );
 
-if ( $opt{config} && -f $opt{config} ) {
-    require $opt{config};
+if ( defined $opt{config} ) {
+    $opt{config} eq "" and $opt{config} = 'smokecurrent_config';
+    read_config( $opt{config} ) or do {
+        my $config_name = File::Spec->catfile( $FindBin::Bin, $opt{config} );
+        read_config( $config_name );
+    };
 
-    foreach my $option ( keys %opt ) {
-        if ( $option eq 'type' ) {
-            $opt{type} ||= $conf->{patch_type};
-        } elsif ( exists $conf->{ $option } ) {
-            $opt{ $option } ||= $conf->{ $option }
+    unless ( Test::Smoke->config_error ) {
+        foreach my $option ( keys %opt ) {
+            if ( $option eq 'type' ) {
+                $opt{type} ||= $conf->{patch_type};
+            } elsif ( exists $conf->{ $option } ) {
+                $opt{ $option } ||= $conf->{ $option }
+            }
         }
+    } else {
+        warn "WARNING: Could not process '$opt{config}': " . 
+             Test::Smoke->config_error . "\n";
     }
 }
 
-$opt{ $_ } ||= $defaults->{ $_ } foreach keys %$defaults;
+$opt{ $_ } ||= $conf->{ $_ } || $defaults->{ $_ } foreach keys %$defaults;
 
 exists $valid_type{ $opt{type} } or do_pod2usage( verbose => 0 );
 
@@ -131,9 +141,9 @@ See:
 
 =over 4
 
-item * http://www.perl.com/perl/misc/Artistic.html
+item * L<http://www.perl.com/perl/misc/Artistic.html>
 
-item * http://www.gnu.org/copyleft/gpl.html
+item * L<http://www.gnu.org/copyleft/gpl.html>
 
 =back
 
